# Init
set datafile commentschars "#abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"
set datafile separator ","
set terminal png size 1280,800
set termoption noenhanced
set encoding utf8
set output sprintf("%s.png",ofilename)
stats filename using 1:($3/$2/125) nooutput
ct = time(0.0)
# Special 'discrete values' cases
discrete = 0
if (strstrt(ofilename,"mp2") == (strlen(ofilename)-2)) {
  discrete = 1
  set ytics 0,64,384
}
if (strstrt(ofilename,"mp3") == (strlen(ofilename)-2)) {
  discrete = 1
  set ytics 0,32,320
}

# Bitrate dependent palette
unset colorbox
h1 = 360/360.0
h2 = 230/360.0
set palette model HSV functions (1-gray)*(h2-h1)+h1,1,0.79
set cbrange [0:STATS_max_y]

# Title
if (discrete) {
  set multiplot layout 2,1 title sprintf("%s (min/av./max: %d / %.1f / %d kbps, %d packets)", ofilename, floor(STATS_min_y+0.5), STATS_mean_y, floor(STATS_max_y+0.5), STATS_records)
}
else {
  set multiplot layout 2,1 title sprintf("%s (min/av./max: %.1f / %.1f / %.1f kbps, %d packets)", ofilename, STATS_min_y, STATS_mean_y, STATS_max_y, STATS_records)
}

# Upper plot
unset key
set xdata time
set xlabel "Time (mm:ss)"
set ylabel "Bitrate (kbps)"
if (STATS_max_x > 600.0) {
  set format x "%H:%M"
  set xlabel "Time (hh:mm)"
}

plot [0:STATS_max_x] [(STATS_min_y<16 ? 0 : STATS_min_y-16):STATS_max_y+16] filename using (ct-ct+$1):($3/$2/125):($3/$2/125) with lines palette

# Lower plot
unset xdata
unset ytics
set ytics autofreq
set xlabel "Bitrate (kbps)"
set ylabel "Frequency (packets)"
set xrange [0:STATS_max_y+16]
set yrange [0:]
unset format

if (discrete) {
  set xtics out nomirror 16
  
  plot filename every ::1::(STATS_records-2) using (floor(($3/$2/125)+0.5)):(1.0) smooth frequency with impulses linewidth 3
}
else {
  # Define boxes width
  width(x)=20*floor(x/20)
  set xtics nomirror 100
  if (STATS_max_y < 640) {
    width(x)=10*floor(x/10)
    set xtics nomirror 50
  }
  if (STATS_max_y < 384) {
    width(x)=5*floor(x/5)
    set xtics nomirror 20
  }
  if (STATS_max_y < 224) {
    width(x)=2*floor(x/2)
    set xtics nomirror 20
  }
  if (STATS_max_y < 160) {
    width(x)=floor(x)
    set xtics nomirror 10
  }
  if ((STATS_max_y-STATS_mean_y) < 2) {
    set boxwidth 2
  }

  plot filename using (width($3/$2/125)):(1.0) smooth frequency with boxes
}

unset multiplot